macro_rules! grpc_client_linked_mod {
    ($($resource:tt),+) => { ... };
}
Generates includes for gRPC client implementations with a linked client service Includes a mock module if the mock feature is enabled