macro_rules! grpc_client_mod { ($($resource:tt),+) => { ... }; }
Generates includes for gRPC client implementations
Includes a mock module if the mock feature is enabled
macro_rules! grpc_client_mod { ($($resource:tt),+) => { ... }; }
Generates includes for gRPC client implementations
Includes a mock module if the mock feature is enabled